Changeset [ccc480ba87bf26dab2defa84a4b65521d1adc404] by Noah Campbell
Revision ccc480ba87bf26dab2defa84a4b65521d1adc404,
committed by Noah Campbell
· November 18th, 2010 @ 04:49 PM
Change xpath parser to use Document and not reread the file each
time. For 1000 evalutes saw time drop from 9s to 7s. Not great, but
it's an improvement.
https://github.com/dtolabs/rundeck/commit/ccc480ba87bf26dab2defa84a...
6 changed files
-
A
core/.classpath -
A
core/.project -
A
core/junit-1591694651.properties -
A
core/junit860154675.properties -
M
core/src/java/com/dtolabs/rundeck/core/authorization/providers/Policies.java -
M
core/src/test/com/dtolabs/rundeck/core/authorization/TestSAREAuthorization.java